# Generated by Django 4.0.10 on 2023-09-22 17:08

# Django
from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("aa_bulletin_board", "0004_model_translation"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="general",
            options={
                "default_permissions": (),
                "managed": False,
                "permissions": (
                    ("basic_access", "Can access this app"),
                    ("manage_bulletins", "Can manage (add/change/remove) bulletins"),
                ),
                "verbose_name": "Bulletin Board",
            },
        ),
    ]
