# Generated by Django 4.2.10 on 2024-02-11 09:40

# Django
from django.db import migrations

# CKEditor
import django_ckeditor_5.fields


class Migration(migrations.Migration):

    dependencies = [
        ("aa_bulletin_board", "0005_alter_general_options"),
    ]

    operations = [
        migrations.AlterField(
            model_name="bulletin",
            name="content",
            field=django_ckeditor_5.fields.CKEditor5Field(
                default=None, verbose_name="Content"
            ),
        ),
    ]
