# Generated by Django 4.0.10 on 2023-06-23 14:38


# Django
from django.conf import settings
from django.db import migrations, models

# AA Bulletin Board
import aa_bulletin_board.models


class Migration(migrations.Migration):
    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ("auth", "0012_alter_user_first_name_max_length"),
        ("aa_bulletin_board", "0003_group_restrictions"),
    ]

    operations = [
        migrations.AlterField(
            model_name="bulletin",
            name="content",
            field=models.TextField(blank=True, verbose_name="Content"),
        ),
        migrations.AlterField(
            model_name="bulletin",
            name="created_by",
            field=models.ForeignKey(
                blank=True,
                default=None,
                null=True,
                on_delete=models.SET(aa_bulletin_board.models.get_sentinel_user),
                related_name="+",
                to=settings.AUTH_USER_MODEL,
                verbose_name="User",
            ),
        ),
        migrations.AlterField(
            model_name="bulletin",
            name="created_date",
            field=models.DateTimeField(
                auto_now_add=True, db_index=True, verbose_name="Created"
            ),
        ),
        migrations.AlterField(
            model_name="bulletin",
            name="groups",
            field=models.ManyToManyField(
                blank=True,
                related_name="aa_bulletin_board_group_restriction",
                to="auth.group",
                verbose_name="Group restrictions",
            ),
        ),
        migrations.AlterField(
            model_name="bulletin",
            name="title",
            field=models.CharField(max_length=255, verbose_name="Title"),
        ),
        migrations.AlterField(
            model_name="bulletin",
            name="updated_date",
            field=models.DateTimeField(
                auto_now=True, null=True, verbose_name="Updated"
            ),
        ),
    ]
